/****************************************************************************
** Meta object code from reading C++ file 'dockdaemonadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dockdaemonadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockdaemonadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DockDaemonAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DockDaemonAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17DockDaemonAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DockDaemonAdaptor",
        "D-Bus Interface",
        "org.deepin.dde.daemon.Dock1",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.dde.daemon.Dock1\">\n    <method na"
        "me=\"RequestDock\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "desktopFile\"/>\n      <arg direction=\"in\" type=\"i\" name=\"ind"
        "ex\"/>\n      <arg direction=\"out\" type=\"b\" name=\"docked\"/>\n"
        "    </method>\n    <method name=\"IsDocked\">\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"desktopFile\"/>\n      <arg direction=\""
        "out\" type=\"b\" name=\"docked\"/>\n    </method>\n    <method nam"
        "e=\"RequestUndock\">\n      <arg direction=\"in\" type=\"s\" name="
        "\"desktopFile\"/>\n      <arg direction=\"out\" type=\"b\" name=\""
        "docked\"/>\n    </method>\n    <method name=\"ActivateWindow\">\n "
        "     <arg direction=\"in\" type=\"u\" name=\"win\"/>\n    </method"
        ">\n    <property access=\"readwrite\" type=\"u\" name=\"WindowSize"
        "Efficient\"/>\n    <property access=\"readwrite\" type=\"u\" name="
        "\"WindowSizeFashion\"/>\n    <property access=\"readwrite\" type=\""
        "i\" name=\"DisplayMode\"/>\n    <property access=\"readwrite\" typ"
        "e=\"i\" name=\"HideMode\"/>\n    <property access=\"readwrite\" ty"
        "pe=\"i\" name=\"Position\"/>\n    <property access=\"read\" type=\""
        "i\" name=\"HideState\"/>\n    <property access=\"readwrite\" type="
        "\"b\" name=\"Locked\"/>\n    <property access=\"read\" type=\"(iii"
        "i)\" name=\"FrontendWindowRect\">\n      <annotation value=\"QRect"
        "\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n  "
        "  <signal name=\"FrontendWindowRectChanged\">\n      <arg directio"
        "n=\"out\" type=\"(iiii)\" name=\"FrontendWindowRect\"/>\n      <an"
        "notation value=\"QRect\" name=\"org.qtproject.QtDBus.QtTypeName.Ou"
        "t0\"/>\n    </signal>\n    <signal name=\"PositionChanged\">\n    "
        "  <arg direction=\"out\" type=\"i\" name=\"Position\"/>\n    </sig"
        "nal>\n    <signal name=\"WindowSizeEfficientChanged\">\n      <arg"
        " direction=\"out\" type=\"u\" name=\"size\"/>\n    </signal>\n    "
        "<signal name=\"WindowSizeFashionChanged\">\n      <arg direction=\""
        "out\" type=\"u\" name=\"size\"/>\n    </signal>\n    <signal name="
        "\"DisplayModeChanged\">\n      <arg direction=\"out\" type=\"i\" n"
        "ame=\"displaymode\"/>\n    </signal>\n    <signal name=\"HideModeC"
        "hanged\">\n      <arg direction=\"out\" type=\"i\" name=\"hideMode"
        "\"/>\n    </signal>\n    <signal name=\"LockedChanged\">\n      <a"
        "rg direction=\"out\" type=\"b\" name=\"locked\"/>\n    </signal>\n"
        "  </interface>\n",
        "DisplayModeChanged",
        "",
        "displaymode",
        "FrontendWindowRectChanged",
        "QRect",
        "FrontendWindowRect",
        "HideModeChanged",
        "hideMode",
        "LockedChanged",
        "locked",
        "PositionChanged",
        "Position",
        "WindowSizeEfficientChanged",
        "size",
        "WindowSizeFashionChanged",
        "ActivateWindow",
        "win",
        "IsDocked",
        "desktopFile",
        "RequestDock",
        "index",
        "RequestUndock",
        "DisplayMode",
        "HideMode",
        "HideState",
        "Locked",
        "WindowSizeEfficient",
        "WindowSizeFashion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'FrontendWindowRectChanged'
        QtMocHelpers::SignalData<void(const QRect &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'HideModeChanged'
        QtMocHelpers::SignalData<void(int)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'LockedChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'PositionChanged'
        QtMocHelpers::SignalData<void(int)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'WindowSizeEfficientChanged'
        QtMocHelpers::SignalData<void(uint)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 18 },
        }}),
        // Signal 'WindowSizeFashionChanged'
        QtMocHelpers::SignalData<void(uint)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 18 },
        }}),
        // Slot 'ActivateWindow'
        QtMocHelpers::SlotData<void(uint)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 21 },
        }}),
        // Slot 'IsDocked'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'RequestDock'
        QtMocHelpers::SlotData<bool(const QString &, int)>(24, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'RequestUndock'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'FrontendWindowRect'
        QtMocHelpers::PropertyData<QRect>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'HideMode'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'HideState'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Position'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WindowSizeEfficient'
        QtMocHelpers::PropertyData<uint>(31, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WindowSizeFashion'
        QtMocHelpers::PropertyData<uint>(32, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DockDaemonAdaptor, qt_meta_tag_ZN17DockDaemonAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DockDaemonAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DockDaemonAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DockDaemonAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DockDaemonAdaptorE_t>.metaTypes,
    nullptr
} };

void DockDaemonAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockDaemonAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->FrontendWindowRectChanged((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 2: _t->HideModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->LockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->PositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->WindowSizeEfficientChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->WindowSizeFashionChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->ActivateWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: { bool _r = _t->IsDocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->RequestDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->RequestUndock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(int )>(_a, &DockDaemonAdaptor::DisplayModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(const QRect & )>(_a, &DockDaemonAdaptor::FrontendWindowRectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(int )>(_a, &DockDaemonAdaptor::HideModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(bool )>(_a, &DockDaemonAdaptor::LockedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(int )>(_a, &DockDaemonAdaptor::PositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(uint )>(_a, &DockDaemonAdaptor::WindowSizeEfficientChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDaemonAdaptor::*)(uint )>(_a, &DockDaemonAdaptor::WindowSizeFashionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->displayMode(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->frontendWindowRect(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->hideMode(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->hideState(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->windowSizeEfficient(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->windowSizeFashion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayMode(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHideMode(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setWindowSizeEfficient(*reinterpret_cast<uint*>(_v)); break;
        case 7: _t->setWindowSizeFashion(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DockDaemonAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockDaemonAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DockDaemonAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DockDaemonAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DockDaemonAdaptor::DisplayModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DockDaemonAdaptor::FrontendWindowRectChanged(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DockDaemonAdaptor::HideModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DockDaemonAdaptor::LockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DockDaemonAdaptor::PositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DockDaemonAdaptor::WindowSizeEfficientChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DockDaemonAdaptor::WindowSizeFashionChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
